==> openwebbeans-2.0.24-source-release.zip: openwebbeans-2.0.24/webbeans-se/src/main/java/org/apache/openwebbeans/se/CDISeLoaderService.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.openwebbeans.se;

import org.apache.webbeans.service.DefaultLoaderService;

import javax.enterprise.inject.spi.Extension;
import java.util.Collection;
import java.util.List;

public class CDISeLoaderService extends DefaultLoaderService
{
    private final Collection<Extension> extensions;
    private final ClassLoader loader;

    public CDISeLoaderService(Collection<Extension> extensions, ClassLoader loader)
    {
        this.extensions = extensions;
        this.loader = loader;
    }

    @Override
    public <T> List<T> load(Class<T> serviceType)
    {
        return load(serviceType, loader);
    }

    @Override
    public <T> List<T> load(Class<T> serviceType, ClassLoader classLoader)
    {
        List<T> loaded = super.load(serviceType, classLoader);
        if (Extension.class == serviceType)
        {
            loaded.addAll(Collection.class.cast(extensions));
        }
        return loaded;
    }
}

==> openwebbeans-4.0.3-source-release.zip: openwebbeans-4.0.3/webbeans-se/src/main/java/org/apache/openwebbeans/se/CDISeLoaderService.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.openwebbeans.se;

import org.apache.webbeans.service.DefaultLoaderService;

import jakarta.enterprise.inject.spi.Extension;
import java.util.Collection;
import java.util.List;

public class CDISeLoaderService extends DefaultLoaderService
{
    private final Collection<Extension> extensions;
    private final ClassLoader loader;

    public CDISeLoaderService(Collection<Extension> extensions, ClassLoader loader)
    {
        this.extensions = extensions;
        this.loader = loader;
    }

    @Override
    public <T> List<T> load(Class<T> serviceType)
    {
        return load(serviceType, loader);
    }

    @Override
    public <T> List<T> load(Class<T> serviceType, ClassLoader classLoader)
    {
        List<T> loaded = super.load(serviceType, classLoader);
        if (Extension.class == serviceType)
        {
            loaded.addAll(Collection.class.cast(extensions));
        }
        return loaded;
    }
}
